@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibExtractor.h"
@@ -91,9 +91,9 @@ int bibExtractor::extract(const QStringList& input_fns, const QString& output_fn
                     logMessage(tr("Error: Unable to create directory %1.").arg(doc_dirname));
             if (doc_dir.exists())
             {
-                const QString CopyMovePdf(_settingsP->value("cb2Bib/CopyMovePdf").toString());
+                const network::Action action(network::actionType(_settingsP->value("cb2Bib/CopyMovePdf").toString()));
                 logMessage(tr("Copying/moving to %1...").arg(target_doc_fn));
-                _networkQP->networkPtr()->getFile(_document_fn, target_doc_fn, CopyMovePdf, this, SLOT(copyMoveEnded(bool)));
+                _networkQP->networkPtr()->getFile(_document_fn, target_doc_fn, action, this, SLOT(copyMoveEnded(bool)));
                 _event_loop->exec();
                 if (_is_copymove_ok)
                 {
@@ -169,7 +169,7 @@ void bibExtractor::extract(const QString& text)
         {
             logMessage(tr("Submitting query..."));
             _settingsP->setValue("networkQuery/isSupervised", false);
-            _networkQP->submitQuery(_bpP->currentReference(), text);
+            _networkQP->submitQuery(_bpP->currentReference(), text, _input_type == PlainText);
             _event_loop->exec();
             _settingsP->setValue("networkQuery/isSupervised", true);
         }
@@ -194,9 +194,9 @@ void bibExtractor::_extract(const QString& text)
     logMessage(_bpP->autoRecognizedString());
 }
 
-void bibExtractor::queryEnded(bool stat, const QString& targetPDF, const QString& targetBib)
+void bibExtractor::queryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib)
 {
-    if (stat)
+    if (succeeded)
     {
         _extract(targetBib);
         if (_input_type == PlainText && _bpP->isAutoRecognized() && !targetPDF.isEmpty())
