@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef BIBEXTRACTOR_H
@@ -60,7 +60,7 @@ private slots:
     void copyMoveEnded(bool ok);
     void logMessage(const QString& ms) const;
     void proxyLogMessage() const;
-    void queryEnded(bool stat, const QString& targetPDF, const QString& targetBib);
+    void queryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib);
 
 };
 
