@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
@@ -90,6 +90,8 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
     }
     else if (field == "doi")
         v.remove(QRegExp("^.+(?=10\\.[\\d\\.]+/\\S+)"));
+    else if (field == "isbn")
+        v.remove(' ');
     else if (field == "journal")
     {
         if (_settingsP->value("cb2Bib/SetJournalsToFullname").toBool())
