@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -688,28 +688,46 @@ void heuristicBibParser::guessJournal(const QString& text)
     stext.remove(c2bUtils::nonLetter);
     QString jn;
     int pos(stext.length() + 1);
+    int jnl(0);
     QStringMatcher blank(" ");
-    for (int i = 0; i < _journal_db.count(); i++)
+    for (int i = 0; i < _journal_db.count(); ++i)
         if (blank.indexIn(_journal_db.retrieveFull(i)) >= 0)
         {
             const int p(stext.indexOf(_journal_db.fullsimplifiedFull(i), 0, Qt::CaseSensitive));
             if (p > -1 && p < pos)
             {
                 pos = p;
+                jnl = _journal_db.fullsimplifiedFull(i).length();
                 jn = _journal_db.retrieve(i);
             }
             else if (p == pos && jn.length() < _journal_db.retrieve(i).length()) // Cases 'Chem Phys' vs 'Chem Phys Lett'
                 jn = _journal_db.retrieve(i);
         }
-    if (!jn.isEmpty())
+    if (!jn.isEmpty() && (pos < 50 || pos + jnl > stext.length() - 50))
     {
         _current_reference["journal"] = _bpP->parse("journal", jn);
         return;
     }
-    for (int i = 0; i < _journal_db.count(); i++)
-        if (stext.contains(_journal_db.fullsimplified(i), Qt::CaseSensitive))
-            if (jn.length() < _journal_db.retrieve(i).length())
-                jn = _journal_db.retrieve(i);
+    QString jheader, jfooter;
+    for (int i = 0; i < _journal_db.count(); ++i)
+    {
+        const int p(stext.indexOf(_journal_db.fullsimplified(i), 0, Qt::CaseSensitive));
+        if (p > -1)
+        {
+            const QString j(_journal_db.retrieve(i));
+            const int jl(j.length());
+            if (jn.length() < jl)
+                jn = j;
+            if (p < 25 && jheader.length() < jl)
+                jheader = j;
+            else if (p + j.length() > stext.length() - 100 && jfooter.length() < jl)
+                jfooter = j;
+        }
+    }
+    if (!jheader.isEmpty())
+        jn = jheader;
+    else if (!jfooter.isEmpty())
+        jn = jfooter;
     if (!jn.isEmpty())
         _current_reference["journal"] = _bpP->parse("journal", jn);
 }
