@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "network.h"
@@ -15,7 +15,7 @@
 #include <QTimer>
 
 
-network::network(QObject* parento) : QObject(parento)
+network::network(QObject* parento) : QObject(parento), _max_redirections(15)
 {
     _is_fetching = false;
     _fetcher = new QNetworkAccessManager(this);
@@ -36,25 +36,36 @@ network::network(QObject* parento) : QObject(parento)
 
 *****************************************************************************/
 
-void network::getFile(const QString& orig, const QString& dest, const QString& action, QObject* receiver, const char* callback,
-                      const bool overwrite)
+void network::getFile(const QString& source, const QString& destination, const Action action,
+                      QObject* receiver, const char* callback, const bool overwrite)
 {
     if (_is_fetching)
     {
-        c2bUtils::warn(tr("network::getFile: File requested while still fetching previous one. Returned"));
+        c2bUtils::warn(tr("network::getFile: Requesting network while still fetching previous request. Returned"));
         return;
     }
-
-    _is_fetching = true;
-    disconnect(this, SIGNAL(getFileDone(bool, const QString&)), 0, 0);
+    setup(source, destination);
+    disconnect(this, SIGNAL(requestFinished(bool)), 0, 0);
     if (receiver)
-        connect(this, SIGNAL(getFileDone(bool, const QString&)), receiver, callback);
-
+        connect(this, SIGNAL(requestFinished(bool)), receiver, callback);
     if (overwrite)
-        if (QFileInfo(dest).exists())
-            QFile::remove(dest);
-    if (!getFilePrivate(orig, dest, action))
-        emit_getFileDone(false, _getfile_error_string);
+        if (QFileInfo(destination).exists())
+            QFile::remove(destination);
+    getFilePrivate(action);
+}
+
+void network::headFile(const QString& source, QObject* receiver, const char* callback)
+{
+    if (_is_fetching)
+    {
+        c2bUtils::warn(tr("network::headFile: Requesting network while still fetching previous request. Returned"));
+        return;
+    }
+    setup(source);
+    disconnect(this, SIGNAL(requestFinished(bool)), 0, 0);
+    if (receiver)
+        connect(this, SIGNAL(requestFinished(bool)), receiver, callback);
+    headFilePrivate();
 }
 
 void network::cancelDownload()
@@ -70,54 +81,69 @@ void network::cancelDownload()
 
 *****************************************************************************/
 
-bool network::getFilePrivate(const QString& orig, const QString& dest, const QString& action)
+void network::getFilePrivate(const Action action)
 {
-    _getfile_error_string.clear();
-    _source_filename = orig;
-    _destination_filename = dest;
     if (!checkDestination())
-        return false;
-
+    {
+        _emit_request_finished(false);
+        return;
+    }
     if (_source_filename.startsWith("<<post>>")) // cb2Bib keyword to use post http method
     {
         _source_filename.remove(QRegExp("^<<post>>"));
-        return getFile_c2b(action, QNetworkAccessManager::PostOperation);
+        _fetch_c2b(action, QNetworkAccessManager::PostOperation);
+        return;
     }
-
     if (FmClient)
-    {
-        if (action == "copy" && !FmClientCopyBin.isEmpty())
-            return getFile_client(action);
-        else if (action == "move" && !FmClientMoveBin.isEmpty())
-            return getFile_client(action);
-    }
-    return getFile_c2b(action);
+        if ((action == Copy && !FmClientCopyBin.isEmpty()) || (action == Move && !FmClientMoveBin.isEmpty()))
+        {
+            _fetch_client(action);
+            return;
+        }
+    _fetch_c2b(action);
 }
 
-void network::emit_getFileDone(bool status, const QString& error)
+void network::headFilePrivate()
 {
-    _getfile_succeeded = status;
-    _getfile_error_string = error;
+    const QUrl u(_source_filename, QUrl::TolerantMode);
+    if (u.scheme() == "file" || QFileInfo(_source_filename).exists())
+    {
+        // Local File
+        const QString fn(u.scheme() == "file" ? u.toLocalFile() : _source_filename);
+        const bool succeeded(QFileInfo(fn).exists());
+        if (!succeeded)
+            _request_error_string = tr("File does not exist.");
+        _emit_request_finished(succeeded);
+    }
+    else
+    {
+        // Network File
+        _head(u);
+    }
+}
+
+void network::_emit_request_finished(bool succeeded)
+{
+    _request_succeeded = succeeded;
     // Give some time to cleanup events and to return all network functions
     // before passing the control to the callback routine
-    QTimer::singleShot(50, this, SLOT(emit_getFileDone()));
+    QTimer::singleShot(50, this, SLOT(_emit_request_finished()));
 }
 
-void network::emit_getFileDone()
+void network::_emit_request_finished()
 {
     _is_fetching = false;
     // Assumed events are clean, all functions returned, then make the callback
-    emit getFileDone(_getfile_succeeded, _getfile_error_string);
+    emit requestFinished(_request_succeeded);
 }
 
 bool network::checkDestination()
 {
-    // Checks whether or not writing to dest is safe
+    // Checks whether or not writing to destination is safe
     // Returns false if file exists
-    QFile f(_destination_filename);
-    if (f.exists())
+    if (QFileInfo(_destination_filename).exists())
     {
-        _getfile_error_string = tr("Destination file '%1' already exists.").arg(_destination_filename);
+        _request_error_string = tr("Destination file '%1' already exists.").arg(_destination_filename);
         return false;
     }
     else
@@ -126,7 +152,7 @@ bool network::checkDestination()
 
 void network::loadSettings()
 {
-    settings* s = settings::instance();
+    settings* s(settings::instance());
     FmClient = s->value("cb2Bib/FmClient").toBool();
     FmClientCopyBin = s->fileName("cb2Bib/FmClientCopyBin");
     FmClientMoveBin = s->fileName("cb2Bib/FmClientMoveBin");
@@ -156,24 +182,24 @@ void network::loadSettings()
 
 *****************************************************************************/
 
-bool network::getFile_client(const QString& action)
+void network::_fetch_client(const Action action)
 {
     // Getting NetworkFile through kfmclient
-    QString c_action(action);
+    Action act(action);
     // Only move local files
     QUrl u(_source_filename);
     if (!(u.scheme() == "file" || QFileInfo(_source_filename).exists()))
-        if (c_action == "move")
-            c_action = "copy"; // Copy network files
+        if (action == Move)
+            act = Copy; // Copy network files
 
     QStringList arglist;
     QString fmclient_bin;
-    if (c_action == "copy")
+    if (act == Copy)
     {
         fmclient_bin = FmClientCopyBin;
         arglist = FmClientCopyArg.split(' ', QString::SkipEmptyParts);
     }
-    else if (c_action == "move")
+    else if (act == Move)
     {
         fmclient_bin = FmClientMoveBin;
         arglist = FmClientMoveArg.split(' ', QString::SkipEmptyParts);
@@ -181,33 +207,30 @@ bool network::getFile_client(const QString& action)
     arglist.append(_source_filename);
     arglist.append(_destination_filename);
     _fetcher_client = new QProcess(this);
-    connect(_fetcher_client, SIGNAL(finished(int, QProcess::ExitStatus)),
-            this, SLOT(fetcherClientEnded(int, QProcess::ExitStatus)));
+    connect(_fetcher_client, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(_client_finished(int, QProcess::ExitStatus)));
     _fetcher_client->start(fmclient_bin, arglist);
-    if (_fetcher_client->waitForStarted())
-        return true;
-    else
+    if (!_fetcher_client->waitForStarted())
     {
-        _getfile_error_string = tr("FM Client '%1' could not be launched.").arg(fmclient_bin);
         delete _fetcher_client;
-        return false;
+        _request_error_string = tr("FM Client '%1' could not be launched.").arg(fmclient_bin);
+        _emit_request_finished(false);
     }
 }
 
-void network::fetcherClientEnded(int exitCode, QProcess::ExitStatus exitStatus)
+void network::_client_finished(int exitCode, QProcess::ExitStatus exitStatus)
 {
+    bool succeeded(false);
     if (exitStatus == QProcess::CrashExit)
-        emit emit_getFileDone(false, tr("Client crashed."));
+        _request_error_string = tr("FM Client crashed.");
     else
     {
-        QFile f(_destination_filename);
-        if (f.exists())
-            emit emit_getFileDone(true, "");
+        if (QFileInfo(_destination_filename).exists())
+            succeeded = true;
         else
-            emit emit_getFileDone(false, tr("File '%1' has not been written. Exit code '%2'.").
-                                  arg(_source_filename).arg(exitCode));
+            _request_error_string = tr("File '%1' has not been written. Exit code '%2'.").arg(_source_filename).arg(exitCode);
     }
     delete _fetcher_client;
+    _emit_request_finished(succeeded);
 }
 
 
@@ -217,20 +240,51 @@ void network::fetcherClientEnded(int exitCode, QProcess::ExitStatus exitStatus)
 
 *****************************************************************************/
 
-bool network::getFile_c2b(const QString& action, const QNetworkAccessManager::Operation op)
+void network::_head(const QUrl& url)
 {
-    _operation = op;
-    _url_query.clear();
-    _redirection_count = 0;
+    QNetworkRequest request;
+    request.setUrl(url);
+    request.setRawHeader("User-Agent", QString("cb2Bib/" + C2B_VERSION + " (Bibliographic Browser Tool)").toLatin1());
+    _current_reply = _fetcher->head(request);
+    connect(_current_reply, SIGNAL(finished()), SLOT(_head_finished()));
+}
+
+void network::_head_finished()
+{
+    if (_redirection_count++ < _max_redirections)
+    {
+        const QUrl redirection(_current_reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl());
+        if (redirection.isValid())
+        {
+            const QUrl ru(_current_reply->url().resolved(redirection));
+            _source_filename = ru.toString();
+            _current_reply->deleteLater();
+            _head(ru);
+            return;
+        }
+    }
+    const bool succeeded(_current_reply->error() == QNetworkReply::NoError);
+    if (succeeded)
+        _file_mimetype_string = _current_reply->header(QNetworkRequest::ContentTypeHeader).toString();
+    else
+        _request_error_string = _current_reply->errorString() + '.';
+    _current_reply->deleteLater();
+    _emit_request_finished(succeeded);
+}
+
+void network::_fetch_c2b(const Action action, const QNetworkAccessManager::Operation operation)
+{
+    _fetch_operation = operation;
+    _fetch_url_query.clear();
     QString url_str;
-    if (_operation == QNetworkAccessManager::PostOperation)
+    if (_fetch_operation == QNetworkAccessManager::PostOperation)
     {
         const int qmark(_source_filename.indexOf('?'));
         url_str = _source_filename.mid(0, qmark);
         if (qmark > -1)
         {
             url_str += '/';
-            _url_query = _source_filename.mid(qmark + 1).toUtf8();
+            _fetch_url_query = _source_filename.mid(qmark + 1).toUtf8();
         }
     }
     else
@@ -240,91 +294,83 @@ bool network::getFile_c2b(const QString& action, const QNetworkAccessManager::Op
     if (u.scheme() == "file" || QFileInfo(_source_filename).exists())
     {
         // Local File
-        QString fn;
-        if (u.scheme() == "file")
-            fn = u.toLocalFile();
-        else
-            fn = _source_filename;
-        QFile orig(fn);
+        QFile source(u.scheme() == "file" ? u.toLocalFile() : _source_filename);
         bool succeeded(false);
-        if (action == "copy")
-            succeeded = orig.copy(_destination_filename);
-        else if (action == "move")
-            succeeded = orig.rename(_destination_filename);
-        if (succeeded)
-            emit_getFileDone(true, "");
-        else
-            _getfile_error_string = orig.errorString();
-        return succeeded;
+        if (action == Copy)
+            succeeded = source.copy(_destination_filename);
+        else if (action == Move)
+            succeeded = source.rename(_destination_filename);
+        if (!succeeded)
+            _request_error_string = source.errorString();
+        _emit_request_finished(succeeded);
     }
     else
     {
         // Network File
-        return fetch(u);
+        _fetch(u);
     }
 }
 
-bool network::fetch(const QUrl& url)
+void network::_fetch(const QUrl& url)
 {
+    _destination_file.setFileName(_destination_filename);
+    if (!_destination_file.open(QIODevice::WriteOnly))
+    {
+        _request_error_string = tr("File '%1' cannot be written. %2").arg(_destination_filename).arg(_destination_file.errorString());
+        _emit_request_finished(false);
+        return;
+    }
     QNetworkRequest request;
     request.setUrl(url);
     request.setRawHeader("User-Agent", QString("cb2Bib/" + C2B_VERSION + " (Bibliographic Browser Tool)").toLatin1());
-    if (_operation == QNetworkAccessManager::PostOperation)
+    if (_fetch_operation == QNetworkAccessManager::PostOperation)
     {
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
-        _current_reply = _fetcher->post(request, _url_query);
+        _current_reply = _fetcher->post(request, _fetch_url_query);
     }
     else
         _current_reply = _fetcher->get(request);
-    connect(_current_reply, SIGNAL(readyRead()), this, SLOT(fetcherReadyRead()));
-    connect(_current_reply, SIGNAL(finished()), SLOT(fetcherEnded()));
+    connect(_current_reply, SIGNAL(readyRead()), this, SLOT(_fetch_ready_read()));
+    connect(_current_reply, SIGNAL(finished()), SLOT(_fetch_finished()));
     connect(_current_reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(logError()));
     connect(_current_reply, SIGNAL(downloadProgress(qint64, qint64)), this, SIGNAL(downloadProgress(qint64, qint64)));
-
-    _destination_file.setFileName(_destination_filename);
-    if (_destination_file.open(QIODevice::WriteOnly))
-        return true;
-    else
-    {
-        _getfile_error_string = tr("File '%1' has not been written. %2").
-                                arg(_destination_filename).arg(_destination_file.errorString());
-        return false;
-    }
 }
 
-void network::fetcherEnded()
+void network::_fetch_finished()
 {
     _destination_file.close();
     if (_current_reply->error() == QNetworkReply::OperationCanceledError)
         _destination_file.remove(); // Delete file
-
-    if (_redirection_count++ < 15)
+    else if (_redirection_count++ < _max_redirections)
     {
-        QUrl redirection = _current_reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
+        const QUrl redirection(_current_reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl());
         if (redirection.isValid())
         {
-            QUrl newUrl = _current_reply->url().resolved(redirection);
+            const QUrl ru(_current_reply->url().resolved(redirection));
+            _source_filename = ru.toString();
             const int status(_current_reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt());
             if ((status >= 301 && status <= 303) || status == 307)
-                _operation = QNetworkAccessManager::GetOperation;
+                _fetch_operation = QNetworkAccessManager::GetOperation;
             _current_reply->deleteLater();
-            fetch(newUrl);
+            _fetch(ru);
             return;
         }
     }
-    if (_current_reply->error() == QNetworkReply::NoError)
-        emit_getFileDone(true, QString());
+    const bool succeeded(_current_reply->error() == QNetworkReply::NoError);
+    if (succeeded)
+        _file_mimetype_string = _current_reply->header(QNetworkRequest::ContentTypeHeader).toString();
     else
-        emit_getFileDone(false, _current_reply->errorString() + '.');
+        _request_error_string = _current_reply->errorString() + '.';
     _current_reply->deleteLater();
+    _emit_request_finished(succeeded);
 }
 
-void network::fetcherReadyRead()
+void network::_fetch_ready_read()
 {
     _destination_file.write(_current_reply->readAll());
 }
 
 void network::logError()
 {
-    c2bUtils::warn(tr("network::QNetworkReply Log: %1").arg(_current_reply->errorString()));
+    c2bUtils::warn(tr("network::QNetworkReply log: %1").arg(_current_reply->errorString()));
 }
