@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "networkQuery.h"
@@ -37,12 +37,13 @@ void networkQuery::init()
     _networkquery_tmp_fn2 = _settingsP->tempPath() + "/cb2bib_query_tmp_html2_" + _settingsP->applicationPid();
 }
 
-void networkQuery::submitQuery(const bibReference& reference, const QString& raw_reference)
+void networkQuery::submitQuery(const bibReference& reference, const QString& raw_reference, const bool check_document)
 {
     // Submission Initialization
     _error_string.clear();
     _query_parameter_count.clear();
     _is_end_of_file = false;
+    _check_document = check_document && _settingsP->value("cb2Bib/AutomaticPdfDownload").toBool();
 
     // Query data
     _Qtitle = reference.value("title");
@@ -74,7 +75,10 @@ void networkQuery::submitQuery1()
     }
     if (_is_end_of_file)
     {
-        _error_string = tr("Performed %1 queries: No reference found.").arg(_query_parameter_count.count());
+        if (_networkP->errorString().isEmpty())
+            _error_string = tr("Performed %1 queries: No reference found.").arg(_query_parameter_count.count());
+        else
+            _error_string = tr("Performed %1 queries: No reference found. %2").arg(_query_parameter_count.count()).arg(_networkP->errorString());
         emit queryEnded(false, _targetQ, _networkquery_tmp_fn1);
         return;
     }
@@ -107,14 +111,14 @@ void networkQuery::submitQuery1()
         emit statusMessage(tr("Importing: %1.").arg(_targetQ));
     else
         emit statusMessage(tr("Query: %1.").arg(_targetQ));
-    _networkP->getFile(_targetQ, _networkquery_tmp_fn1, "copy",
+    _networkP->getFile(_targetQ, _networkquery_tmp_fn1, network::Copy,
                        this, SLOT(submitQuery2(bool)), !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
 }
 
-void networkQuery::submitQuery2(bool stat)
+void networkQuery::submitQuery2(bool succeeded)
 {
-    // Submission, second part: extracting reference location
-    if (!stat)
+    // Submission, second part: check query replay and PDF existence
+    if (!succeeded)
     {
         _error_string = _networkP->errorString();
         emit statusMessage(tr("Query failed with %1.").arg(_error_string));
@@ -142,13 +146,27 @@ void networkQuery::submitQuery2(bool stat)
         QTimer::singleShot(10, this, SLOT(submitQuery1()));
         return;
     }
-    _targetBib = _referenceurl_prefix + lines + _referenceurl_sufix;
-    if (_pdfurl_prefix.isEmpty() && _pdfurl_sufix.isEmpty())
-        _targetPDF.clear();
-    else if (_settingsP->value("cb2Bib/AutomaticPdfDownload").toBool())
-        _targetPDF = _pdfurl_prefix + lines + _pdfurl_sufix;
-
     c2bUtils::debug(tr("CAPTURED[%1]").arg(lines));
+
+    _targetBib = _referenceurl_prefix + lines + _referenceurl_sufix;
+    if (_check_document && !_pdfurl_prefix.isEmpty())
+    {
+        _targetPDF = _pdfurl_prefix + lines + _pdfurl_sufix;
+        emit statusMessage(tr("Checking: %1.").arg(_targetPDF));
+        _networkP->headFile(_targetPDF, this, SLOT(submitQuery3(bool)));
+    }
+    else
+        submitQuery3(false);
+}
+
+void networkQuery::submitQuery3(bool succeeded)
+{
+    // Submission, third part: extracting reference location
+    if (!succeeded || !_networkP->mimetypeString().contains(QRegExp("\\b(chm|djvu|pdf|ps)\\b")))
+        _targetPDF.clear();
+    else
+        _targetPDF = _networkP->sourceFilename();
+
     c2bUtils::debug(tr("POST2[%1]").arg(_targetBib));
     c2bUtils::debug(tr("POST3[%1]").arg(_targetPDF));
 
@@ -170,14 +188,14 @@ void networkQuery::submitQuery2(bool stat)
         emit statusMessage(tr("Importing: %1.").arg(_targetBib));
     else
         emit statusMessage(tr("Retrieving: %1.").arg(_targetBib));
-    _networkP->getFile(_targetBib, _networkquery_tmp_fn2, "copy",
+    _networkP->getFile(_targetBib, _networkquery_tmp_fn2, network::Copy,
                        this, SLOT(queryDone(bool)), !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
 }
 
-void networkQuery::queryDone(bool stat)
+void networkQuery::queryDone(bool succeeded)
 {
     // Submission Done
-    if (!stat)
+    if (!succeeded)
     {
         _error_string = _networkP->errorString();
         emit queryEnded(false, _targetBib, _networkquery_tmp_fn2);
