@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef NETWORKQUERY_H
@@ -31,7 +31,7 @@ public:
     networkQuery(bibParser* bp, network* net, QObject* parento = 0);
     inline virtual ~networkQuery() {}
 
-    void submitQuery(const bibReference& reference, const QString& raw_reference = QString());
+    void submitQuery(const bibReference& reference, const QString& raw_reference, const bool check_document);
     inline QString errorString() const
     {
         return _error_string;
@@ -42,7 +42,7 @@ public:
     }
 
 signals:
-    void queryEnded(bool stat, const QString& targetPDF, const QString& targetBib);
+    void queryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib);
     void statusMessage(const QString& ms);
 
 
@@ -85,6 +85,7 @@ private:
     QString _targetPDF;
     QString _targetQ;
     bibParser* _bpP;
+    bool _check_document;
     bool _is_end_of_file;
     const QString encodeUrl(const QString& url) const;
     network* _networkP;
@@ -95,9 +96,10 @@ private:
 private slots:
     bool areQueryParametersValid();
     bool setQueryParameters();
-    void queryDone(bool stat);
+    void queryDone(bool succeeded);
     void submitQuery1();
-    void submitQuery2(bool stat);
+    void submitQuery2(bool succeeded);
+    void submitQuery3(bool succeeded);
     void updateQueryPlaceholders();
 
 };
