@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bExport.h"
@@ -39,13 +39,13 @@ void c2bExport::exportEntries(const export_data& ed)
             continue;
         if (ed.copy_documents)
         {
-            QString ofn(ref.value("file"));
-            if (!ofn.isEmpty())
+            QString sfn(ref.value("file"));
+            if (!sfn.isEmpty())
             {
-                QString dfn(c2bUtils::documentAbsoluteName(ed.relative_dir, ed.export_fn, ed.documents_dir, ofn));
-                QFile orig(ofn);
-                if (!orig.copy(dfn))
-                    export_log += tr("% Unable to copy file %1 to %2. %3.\n").arg(ofn).arg(dfn).arg(orig.errorString());
+                QString dfn(c2bUtils::documentAbsoluteName(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
+                QFile source(sfn);
+                if (!source.copy(dfn))
+                    export_log += tr("% Unable to copy file %1 to %2. %3.\n").arg(sfn).arg(dfn).arg(source.errorString());
                 if (QFileInfo(dfn).exists())
                 {
                     const int pos(filere.indexIn(ref.rawReference, 0));
@@ -53,7 +53,7 @@ void c2bExport::exportEntries(const export_data& ed)
                     {
                         QString line(filere.cap(0));
                         QString file(filere.cap(1));
-                        line.replace(file, c2bUtils::documentFilename(ed.relative_dir, ed.export_fn, ed.documents_dir, ofn));
+                        line.replace(file, c2bUtils::documentFilename(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
                         ref.rawReference.replace(pos, filere.matchedLength(), line);
                     }
                 }
