@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bHighlighter.h"
@@ -15,7 +15,7 @@ c2bHighlighter::c2bHighlighter(QTextDocument* doc) : QSyntaxHighlighter(doc)
 {
     QPalette p;
     text_color = p.text().color();
-    c2bSettings* settings = c2bSettingsP;
+    c2bSettings* settings(c2bSettingsP);
     c = &settings->colors;
     connect(settings, SIGNAL(newSettings()), this, SLOT(rehighlight()));
 
