@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -119,7 +119,7 @@
     To test and learn about automatic extractions, the cb2Bib distribution
     includes a set of four PDF files that mimic a paper title page. For these
     files, distribution also includes a regular expression, in file
-    <tt>regexps.txt</tt> capable of extracting the reference fields, provided
+    <tt>regexps.txt</tt>, capable of extracting the reference fields, provided
     the <tt>pdftotex</tt> flags are set to their default values. Processing
     these files, should, therefore, be automatic, and four messages stating
     <tt>Processed as 'PDF Import Example'</tt> should be seen in the logs. Note
@@ -131,7 +131,7 @@
     that some of the files, while being processed, are not renamed and their
     corresponding BibTeX data is not written. For each document file, cb2Bib
     converts its first page to text, and from this text it attempts to extract
-    the bibliographic reference. By design, when extraction fails, cb2bib does
+    the bibliographic reference. By design, when extraction fails, cb2Bib does
     nothing: no file is moved, no BibTeX is written. This way, you know that
     the remaining files in the origin directory need special, manual attention.
     <b>Extractions are always seen as failed, unless reliable data is found in
@@ -140,7 +140,7 @@
     - <b>What is <em>reliable data</em>?</b>
     Note that computer processing of natural texts, as extracting the
     bibliographic data from a title page, is nowadays an approximated
-    procedure. The cb2bib tries several strategies: <b>1)</b> allow for
+    procedure. The cb2Bib tries several strategies: <b>1)</b> allow for
     including user regular expressions very specific to the extraction at hand,
     <b>2)</b> use metadata if available, <b>3)</b> guess what is reasonable,
     and, based on this, make customized queries. Then, cb2Bib considers
