@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPostprocess.h"
@@ -29,7 +29,7 @@ c2bPostprocess::c2bPostprocess(const QString& fn, QWidget* parentw) : QDialog(pa
     ui.buttonBox->button(QDialogButtonBox::Close)->setEnabled(false);
     connect(ui.buttonBox, SIGNAL(helpRequested()), this, SLOT(help()));
     connect(_buttonOpenFile, SIGNAL(clicked()), this, SLOT(openFile()));
-    c2bSettings* settings = c2bSettingsP;
+    c2bSettings* settings(c2bSettingsP);
     resize(settings->value("c2bLogWidget/size", size()).toSize());
     PPBIBTEX_BIN = settings->fileName("cb2Bib/PostprocessBibTeXBin");
     PPBIBTEX_ARG = settings->value("cb2Bib/PostprocessBibTeXArg").toString();
