@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bRLWebSearchSettings.h"
@@ -12,7 +12,7 @@ c2bRLWebSearchSettings::c2bRLWebSearchSettings(QWidget* parentw) : QDialog(paren
 {
     ui.setupUi(this);
     resize(size().width(), 1);
-    c2bSettings* settings = c2bSettingsP;
+    c2bSettings* settings(c2bSettingsP);
     const QString searchEngine(settings->value("c2bReferenceList/SearchEngine").toString());
     ui.searchEngine->addItem(searchEngine);
     ui.searchEngine->addItem("http://www.google.com/search?ie=UTF-8&q=");
@@ -29,7 +29,7 @@ c2bRLWebSearchSettings::~c2bRLWebSearchSettings()
 
 void c2bRLWebSearchSettings::accept()
 {
-    c2bSettings* settings = c2bSettingsP;
+    c2bSettings* settings(c2bSettingsP);
     settings->setValue("c2bReferenceList/SearchEngine", ui.searchEngine->currentText());
     settings->setValue("c2bReferenceList/SearchEngineAddQuotes", ui.addQuotes->isChecked());
     QDialog::accept();
