@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSaveRegExp.h"
@@ -111,7 +111,7 @@ c2bSaveRegExp::c2bSaveRegExp(const QStringList& pattern, const QString& input, Q
     Q_ASSERT_X(pattern.count() == 3, "c2bSaveRegExp", "Expected exactly three strings for pattern");
     ui.setupUi(this);
     connect(ui.buttonBox, SIGNAL(helpRequested()), this, SLOT(help()));
-    c2bSettings* settings = c2bSettingsP;
+    c2bSettings* settings(c2bSettingsP);
     ui.Input->setFont(settings->c2bMonoFont);
     ui.Type->setText(pattern.at(0));
     ui.Fields->setText(pattern.at(1));
