@@ -1,11 +1,12 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
 #define C2B_CHECK_CODE_DECOMPOSITION 0
+#define C2B_CHECK_JOURNALS 0
 #define C2B_CHECK_PATTERNS 0
 #define C2B_CHECK_PDF_CODES 0
 #include "c2bTests.h"
@@ -40,14 +41,16 @@ int c2bTests::allTests()
 {
     _test_count = 0;
     _failed_test_count = 0;
-
+#if C2B_CHECK_JOURNALS
+    heuristic_journal();
+#else
     author_parser();
     heuristic_pvny();
     heuristic_misc();
     heuristic_author();
     heuristic_check_patterns();
     compression_check();
-
+#endif
     cout << endl << endl;
     cout << "Tests done. Tests: " << _test_count << " Failed: " << _failed_test_count << endl;
     return 0;
@@ -299,6 +302,98 @@ void c2bTests::heuristic_author()
     _failed_test_count += n_failed_pdf;
 }
 
+void c2bTests::heuristic_journal()
+{
+#if C2B_CHECK_JOURNALS
+    cout << endl;
+    cout << "-----------------------------------------" << endl;
+    cout << "Test heuristic journal recognition on PDF" << endl;
+    cout << "-----------------------------------------" << endl;
+    cout << endl;
+    cout << "Checking files at: " << _bibliographic_dir << endl;
+
+    QFileInfoList flist = QDir(_bibliographic_dir).entryInfoList(QStringList() << "*.bib");
+    bibParser bp;
+    bibReference reference;
+    QStringList fields;
+    fields.append("journal");
+    fields.append("file");
+
+    const QStringList excluded(c2bUtils::fileToString(_bibliographic_dir + "/c2b_test_exclude.txt")
+                               .split(QRegExp("[\\n\\r]"), QString::SkipEmptyParts));
+    QHash<QString, QString> doc_cache;
+    const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
+    if (QFileInfo(doc_cache_fn).exists())
+    {
+        cout << "Reading from cache" << endl;
+        QFile file(doc_cache_fn);
+        file.open(QIODevice::ReadOnly);
+        QDataStream ds(&file);
+        ds >> doc_cache;
+    }
+    else
+    {
+        cout << "No cache. Return" << doc_cache_fn << endl;
+        return;
+    }
+    cout << "Check journals" << endl;
+    int n_pdf(0);
+    int n_failed_pdf(0);
+    for (int f = 0; f < flist.count(); ++f)
+    {
+        const QString bib_file(flist.at(f).absoluteFilePath());
+        bp.initReferenceParsing(_bibliographic_dir, fields, &reference);
+        cout << "File: " << bib_file << endl;
+        while (bp.referencesIn(c2bUtils::fileToString(bib_file), &reference))
+        {
+            const QString file(reference.value("file"));
+            if (file.isEmpty())
+                continue;
+            if (excluded.contains(file) || file.contains("/stacks/"))
+                continue;
+            const QString doc(doc_cache.value(file));
+            QString check_doc(doc);
+            check_doc.remove(c2bUtils::nonAsciiLetter);
+            if (check_doc.isEmpty())
+                continue;
+            const QString journal(bp.abbreviatedJournal(reference.value("journal")));
+            if (journal.isEmpty())
+                continue;
+            if (journal == bp.fullJournal(journal) && (journal.count('.') > 0 || journal.count(' ') > 0))
+            {
+                qDebug() << "not in db:" << journal;
+                continue;
+            }
+            bp.clearCurrentReference();
+            bp.guessFields(doc);
+            const QString guess(bp.abbreviatedJournal(bp.currentReference().value("journal")));
+            if (guess.isEmpty())
+                continue;
+
+            bool passed(guess == journal);
+            if (!passed)
+            {
+                cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(journal);
+                cout << QString("          '%1'\n").arg(guess);
+
+                qDebug() << "jn:" << journal;
+                qDebug() << "gn:" << guess;
+                qDebug() << reference.value("file");
+                qDebug() << "DOCUMENT: \n" << doc << endl << endl;
+            }
+            else
+                cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(journal);
+            ++n_pdf;
+            if (!passed) ++n_failed_pdf;
+        }
+    }
+    cout << "PDF Tests: " << n_pdf << endl;
+    cout << "Succeded: " << n_pdf - n_failed_pdf << endl;
+    _test_count += n_pdf;
+    _failed_test_count += n_failed_pdf;
+#endif
+}
+
 void c2bTests::author_parser()
 {
     cout << endl;
