@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2004-2010 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.4.0. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 1.4.1. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "cb2Bib.h"
@@ -47,7 +47,7 @@
     detailed list of changes and acknowledgments, and \ref relnotes for
     additional notes and information.)
 
-    See also \ref relnotes140
+    See also \ref relnotes140.
 
 <p>&nbsp;</p>
 
@@ -238,7 +238,7 @@
     - <b>Alt D</b> \n Deletes temporary BibTeX output file. This permits using
     cb2Bib output files as temporary media to transfer references to a
     preferred reference manager and preferred format. <b>Caution</b>: This
-    feature is not intended for the users that actually store their references
+    feature is not intended for the users who actually store their references
     in one or several BibTeX files. Remember to import references prior to
     delete cb2Bib output file.
 
@@ -345,9 +345,9 @@
     included in Qt > 4.4.0 library. No special action/flag is needed during
     compilation.
 
-    - LZO2 library and headers, available at
+    - LZO 2.03 library and headers available at
     \htmlonly
-    <a href="http://www.oberhumer.com/opensource/lzo/" target="_blank">http://www.oberhumer.com/opensource/lzo/</a>.
+    <a href="http://www.oberhumer.com/opensource/lzo/" target="_blank">http://www.oberhumer.com/opensource/lzo</a>.
     \endhtmlonly
      If LZO2 were unavailable on a particular platform, type <tt>configure --disable-lzo</tt>
      or, equivalently, <tt>qmake -config disable-lzo</tt> before compiling.
@@ -365,13 +365,13 @@
 
     - <tt>jsMath</tt>, available at
     \htmlonly
-    <a href="http://www.math.union.edu/~dpvc/jsMath/" target="_blank">http://www.math.union.edu/~dpvc/jsMath/</a>,
+    <a href="http://www.math.union.edu/~dpvc/jsMath/" target="_blank">http://www.math.union.edu/~dpvc/jsMath</a>,
     \endhtmlonly
     for displaying mathematical notation. Simply, download and unzip it in a desired directory.
 
     - <tt>ExifTool</tt>, version 7.31 or later, available at
     \htmlonly
-    <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/" target="_blank">http://www.sno.phy.queensu.ca/~phil/exiftool/</a>.
+    <a href="http://www.sno.phy.queensu.ca/~phil/exiftool/" target="_blank">http://www.sno.phy.queensu.ca/~phil/exiftool</a>.
     \endhtmlonly
 
     - <tt>pdftotext</tt>, found packaged as <tt>xpdf</tt>, and downloadable from
@@ -1367,7 +1367,6 @@ void cb2Bib::on_addBibB_clicked()
     }
     else
     {
-        const QString CopyMovePdf(_settingsP->value("cb2Bib/CopyMovePdf").toString());
         _target_document_file = c2bUtils::documentAbsoluteName(_settingsP->value("cb2Bib/RelativePdfDirectory").toBool(),
                                 ui.bibtexfile->currentText(), _settingsP->fileName("cb2Bib/PdfDirectory"), ui.file->text());
         const QString doc_dir_name(QFileInfo(_target_document_file).absolutePath());
@@ -1380,6 +1379,7 @@ void cb2Bib::on_addBibB_clicked()
                 ui.addBibB->setEnabled(_modified);
                 return;
             }
+        const network::Action CopyMovePdf(network::actionType(_settingsP->value("cb2Bib/CopyMovePdf").toString()));
         c2b::net()->getFile(_dropped_document_file, _target_document_file, CopyMovePdf, this, SLOT(addToFile(bool)));
     }
 }
@@ -2090,12 +2090,12 @@ void cb2Bib::makeNetQuery()
     }
     ui.makeNetworkQueryB->setEnabled(false);
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-    _netQP->submitQuery(_bpP->currentReference(), ClipEdit->toPlainText());
+    _netQP->submitQuery(_bpP->currentReference(), ClipEdit->toPlainText(), !_pdfImportP);
 }
 
-void cb2Bib::netQueryEnded(bool stat, const QString& targetPDF, const QString& targetBib)
+void cb2Bib::netQueryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib)
 {
-    if (!stat)
+    if (!succeeded)
     {
         emit endedProcessing(false);
         c2b::showMessage(tr("Query submission error. %1").arg(_netQP->errorString()));
